@@ -1,4 +1,4 @@
-from ptrace.cpu_info import CPU_X86_64, CPU_I386, CPU_PPC64, CPU_PPC32
+from ptrace.cpu_info import CPU_X86_64, CPU_I386, CPU_PPC64, CPU_PPC32, CPU_AARCH64, CPU_RISCV32, CPU_RISCV64
 from ptrace.os_tools import RUNNING_LINUX, RUNNING_FREEBSD
 if RUNNING_LINUX:
     if CPU_X86_64:
@@ -9,6 +9,12 @@ if RUNNING_LINUX:
         from ptrace.syscall.linux.powerpc64 import SYSCALL_NAMES, SOCKET_SYSCALL_NAMES
     elif CPU_PPC32:
         from ptrace.syscall.linux.powerpc32 import SYSCALL_NAMES, SOCKET_SYSCALL_NAMES
+    elif CPU_AARCH64:
+        from ptrace.syscall.linux.aarch64 import SYSCALL_NAMES, SOCKET_SYSCALL_NAMES
+    elif CPU_RISCV32:
+        from ptrace.syscall.linux.riscv32 import SYSCALL_NAMES, SOCKET_SYSCALL_NAMES
+    elif CPU_RISCV64:
+        from ptrace.syscall.linux.riscv64 import SYSCALL_NAMES, SOCKET_SYSCALL_NAMES
     else:
         raise NotImplementedError("Unsupported CPU architecture")
 
